==> haskell-monad-logger-0.3.18-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-monad-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.18
id: monad-logger-0.3.18-7704b739a8ba950a4b62906c3ab56228
key: monad_062lSdRs9oE1cVU0M7qU5X
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A class of monads which can log messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/monad-logger>.
category: System
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Logger
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-logger-0.3.18
hs-libraries: HSmonad-logger-0.3.18-062lSdRs9oE1cVU0M7qU5X
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-loops-0.4.3-b8dcb4f8d0b758186f0f7001488f9c96
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    stm-chans-3.0.0.4-b9497ea62b3d0161f6f6b1f5b4ed3526
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.18-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-monad-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.18
id: monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
key: monad_C35svQH7cmcFF0rmqB4WW2
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A class of monads which can log messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/monad-logger>.
category: System
author: Michael Snoyman
exposed: True
exposed-modules:
    Control.Monad.Logger
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-logger-0.3.18
hs-libraries: HSmonad-logger-0.3.18-C35svQH7cmcFF0rmqB4WW2
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-loops-0.4.3-b8dcb4f8d0b758186f0f7001488f9c96
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    stm-chans-3.0.0.4-b9497ea62b3d0161f6f6b1f5b4ed3526
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
